@@ -369,7 +369,7 @@ if __name__=="__main__":
 
     # dynamicFunctions["desligarImportacaoNuvideo"]()
 
-    putStatusRobo(EnumStatus.DESLIGADO, EnumProcesso.CONFIRMACAO_CREDITO, EnumBanco.PAN)
+    putStatusRobo(EnumStatus.LIGADO, EnumProcesso.INTEGRACAO, EnumBanco.PRESENCA_BANK)
     # putStatusRobo(EnumStatus.LIGADO, EnumProcesso.CRIACAO, EnumBanco.BMG)
     # putStatusRobo(EnumStatus.LIGADO, EnumProcesso.CRIACAO, EnumBanco.C6)
     # postSolicitacao(None, EnumProcesso.CRIACAO, 123345, EnumBanco.BANRISUL)
